************************
Related Python libraries
************************

scikits.statsmodels
-------------------

scikits.timeseries
------------------

:mod:`scikits.timeseries` provides a data structure for fixed
frequency time series data based on the numpy.MaskedArray class. For
time series data, it provides much of the same functionality to the
pandas Series class. It has many more functions for time
series-specific manipulation.

In designing